@@ -1,9 +1,11 @@
 package Web::Query;
+our $AUTHORITY = 'cpan:TOKUHIROM';
+# ABSTRACT: Yet another scraping library like jQuery
+$Web::Query::VERSION = '0.31';
 use strict;
 use warnings;
 use 5.008001;
 use parent qw/Exporter/;
-our $VERSION = '0.30';
 use HTML::TreeBuilder::XPath;
 use LWP::UserAgent;
 use HTML::Selector::XPath 0.06 qw/selector_to_xpath/;
@@ -20,7 +22,7 @@ sub wq { Web::Query->new(@_) }
 our $UserAgent = LWP::UserAgent->new();
 
 sub __ua {
-    $UserAgent ||= LWP::UserAgent->new( agent => __PACKAGE__ . "/" . $VERSION );
+    $UserAgent ||= LWP::UserAgent->new( agent => __PACKAGE__ . "/" . __PACKAGE__->VERSION );
     $UserAgent;
 }
 
@@ -239,7 +241,12 @@ sub tagname {
 sub each {
     my ($self, $code) = @_;
     my $i = 0;
-    for my $tree (@{$self->{trees}}) {
+
+    # make a copy such that if we modify the list via 'delete',
+    # it won't change from under our feet (see t/each-and-delete.t 
+    # for a case where it can)
+    my @trees = @{ $self->{trees} };
+    for my $tree ( @trees ) { 
         local $_ = (ref $self || $self)->new_from_element([$tree], $self);
         $code->($i++, $_);
     }
@@ -276,6 +283,10 @@ sub filter {
     return (ref $self || $self)->new_from_element(\@new, $self);
 }
 
+sub _is_same_node {
+    refaddr($_[1]) == refaddr($_[2]);
+}
+
 sub remove {
     my $self = shift;
     my $before = $self->end;
@@ -283,7 +294,7 @@ sub remove {
     while (defined $before) {
         @{$before->{trees}} = grep {
             my $el = $_;            
-            not grep { refaddr($el) == refaddr($_) } @{$self->{trees}};            
+            not grep { $self->_is_same_node( $el, $_ ) } @{$self->{trees}};            
         } @{$before->{trees}};
 
         $before = $before->end;
@@ -543,7 +554,6 @@ sub next_until {
 }
 
 sub last_response {
-    my ($class) = @_;
     return $RESPONSE;
 }
 
@@ -555,16 +565,21 @@ sub DESTROY {
 }
 
 1;
+
 __END__
 
-=encoding utf8
+=pod
 
-=for stopwords prev
+=encoding UTF-8
 
 =head1 NAME
 
 Web::Query - Yet another scraping library like jQuery
 
+=head1 VERSION
+
+version 0.31
+
 =head1 SYNOPSIS
 
     use Web::Query;
@@ -591,9 +606,10 @@ passed as a scalar ref, it'll be taken as a straight XPath expression.
     $wq( '<div><p>hello</p><p>there</p></div>' )->find( 'p' );       # css selector
     $wq( '<div><p>hello</p><p>there</p></div>' )->find( \'/div/p' ); # xpath selector
 
-
 B<THIS LIBRARY IS UNDER DEVELOPMENT. ANY API MAY CHANGE WITHOUT NOTICE>.
 
+=for stopwords prev
+
 =head1 FUNCTIONS
 
 =over 4
@@ -710,7 +726,7 @@ Reduce the elements to those that pass the function's test.
 Get the descendants of each element in the current set of matched elements, filtered by a selector.
 
     my $q2 = $q->find($selector); # $selector is a CSS3 selector.
-    
+
 B<NOTE> If you want to match the element itself, use L</filter>.
 
 B<INCOMPATIBLE CHANGE> 
@@ -789,7 +805,7 @@ Insert content, specified by the parameter, after each element in the set of mat
                                ->after('<b>bar</b>')
                                ->end
                                ->as_html; # <div><p>foo</p><b>bar</b></div>
-    
+
 The content can be anything accepted by L</new>.
 
 =head3 append
@@ -797,7 +813,7 @@ The content can be anything accepted by L</new>.
 Insert content, specified by the parameter, to the end of each element in the set of matched elements.
 
     wq('<div></div>')->append('<p>foo</p>')->as_html; # <div><p>foo</p></div>
-    
+
 The content can be anything accepted by L</new>.
 
 =head3 as_html
@@ -830,7 +846,7 @@ Insert content, specified by the parameter, before each element in the set of ma
                                ->before('<b>bar</b>')
                                ->end
                                ->as_html; # <div><b>bar</b><p>foo</p></div>
-    
+
 The content can be anything accepted by L</new>.
 
 =head3 clone
@@ -914,7 +930,7 @@ Get/Set the text.
     my $text = $q->text(); # 1st matching element only
 
     $q->text('text');
-    
+
 If called in a scalar context, only return the string representation
 of the first element
 
@@ -959,4 +975,13 @@ Copyright (C) Tokuhiro Matsuno
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/tokuhirom/Web-Query/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
