@@ -1,43 +1,27 @@
 package Web::Query::LibXML;
+our $AUTHORITY = 'cpan:TOKUHIROM';
+# ABSTRACT: fast, drop-in replacement for Web::Query
+$Web::Query::LibXML::VERSION = '0.31';
+
 use 5.008005;
 use strict;
 use warnings;
 use parent qw/Web::Query Exporter/;
 use HTML::TreeBuilder::LibXML;
 
-
-our $VERSION = "0.30";
-
 our @EXPORT = qw/wq/;
 
 sub wq { Web::Query::LibXML->new(@_) }
 
 sub _build_tree {
-    my $class = shift;
     my $tree = HTML::TreeBuilder::LibXML->new();
     $tree->ignore_unknown(0);
     $tree->store_comments(1);
     $tree;    
 }
 
-# TODO use Web::Query remove
-sub remove {
-    my $self = shift;
-    my $before = $self->end;
-    
-    while (defined $before) {
-        @{$before->{trees}} = grep {
-            my $el = $_;            
-            not grep { $el->{node}->isSameNode($_->{node}) } @{$self->{trees}};            
-        } @{$before->{trees}};
-
-        $before = $before->end;
-    }
-    
-    $_->delete for @{$self->{trees}};
-    @{$self->{trees}} = ();
-
-    $self;
+sub _is_same_node {
+    $_[1]->{node}->isSameNode($_[2]->{node});
 }
 
 sub prev {
@@ -68,14 +52,21 @@ sub tagname {
 
 sub _node_id { $_[1]{node}->unique_key }
 1;
+
 __END__
 
+=pod
+
 =encoding utf-8
 
 =head1 NAME
 
 Web::Query::LibXML - fast, drop-in replacement for Web::Query
 
+=head1 VERSION
+
+version 0.31
+
 =head1 SYNOPSIS
 
     use Web::Query::LibXML; 
@@ -83,7 +74,6 @@ Web::Query::LibXML - fast, drop-in replacement for Web::Query
     # imports wq()
     # all methods inherited from Web::Query
     # see Web::Query for documentation  
-    
 
 =head1 DESCRIPTION
 
@@ -119,5 +109,13 @@ Carlos Fernando Avila Gratz E<lt>cafe@q1software.comE<gt>
 
 L<Web::Query>, L<HTML::TreeBuilder::LibXML>, L<XML::LibXML> 
 
-=cut
+=head1 BUGS
 
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/tokuhirom/Web-Query/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=cut
